@@ -137,7 +137,7 @@ def get_test_modules(gis_enabled):
                     "." in f.name
                     or os.path.basename(f.name) in subdirs_to_skip
                     or f.is_file()
-                    or not os.path.exists(os.path.join(f.path, "__init__.py"))
+                    or not os.path.exists(os.path.join(f.path, "manage.py-tpl"))
                 ):
                     continue
                 test_module = f.name
